!-------------------------------------------------------------------
! 2D POTENTIAL OF THE CN- ---------- AR SYSTEM FOR THE RIGID ROTOR !
!       CN-  DIATOM KEPT FROZEN AT ITS EQUILIBRIUM GEOMETRY        !
!                    R-THETA 2D POTENTIAL                          !
!                       CUBIC SPLINES                              !
!------------------------------------------------------------------!
!                      Energies in wavenumbers                     !
!           (ZERO ENERGY IS SET TO  CN(req) ----------He)          !
!                      Distances in angstrom                       !
!------------------------------------------------------------------!
!                      03  JUNE 2020                               !
!------------------------------------------------------------------!
! re= C-N  ;  x1= ang(Ar -- com_cn -- C)  ;  x2= com_cn --- Ar     !
!                   Ar                                             !
!                     \                                            !
!                      \                                           !
!                    x2 \                                          !  
!                        \                                         !   
!                     x1--\                                        !    
!                      |   \                                       !     
!                 C--------------N                                 !
!                          re                                      !     
!                                                                  !     
!------------------------------------------------------------------!
! CN anion - Ar pes
! Molpro CCSD(T) CBS extrapolation using aug-cc-pVTZ:aug-cc-pVQZ:aug-cc-pV5Z
! BSSE corrections are done only in V values.
!
! Jacobi coordinates
! R is the distance from Ar to the center-of-mass of CN 
! mC=12.0107
! mN=14.0067
! rcn=1.181431
! rn=(mc/(mc+mn))*rcn
! rc=(mn/(mc+mn))*rcn
! theta is the angle Ar-COM of CN-C
! 
!q                                                                               
!C  1  rc                                                                      
!q  1  1.0  2  90.0                                                              
!N  1  rn   3  90.0   2  180.0                                                  
!Ar 1  rar  2  theta  3  0.0 
!
!  V is BSSE corrected energy from CBS in meV
!  E is energy from CBS in au (no BSSE corrected)
!
! file: cnmar_abinitio.dat
!
!    R(CN)    Theta      R         V(meV)         E(au) 
!---------   ------  -------      --------  --------------                                      

      implicit double precision(a-h,o-z)
      parameter(m=19,n=56)  
      parameter(x1min=0.d0,x1max=180.d0,x2min=2.5d0,x2max=25.d0)
      parameter(nang=720,npun=500)
      real*8 x1,x2,y,x,dum
      common/pot2d/ x1a(m),x2a(n),y2a(m,n),ya(m,n),vref
      h2cm=4.55633D-6 ! / hartree to cm-1 
      ev2cm=8.065544D0 ! * meV to cm-1
      dr=(x2max-x2min)/npun
      da=(x1max-x1min)/nang


      open(5,file='cnmar_abinitio.dat')

      do i=1,m
       do j=1,n
        read(5,*)dum,x1a(i),x2a(j),ya(i,j),dum
!        read(5,*)dum,x1a(i),x2a(j),dum,ya(i,j)
       enddo
      enddo
      close(6)
      close(5)
100   format (5(2x,f15.8)) 

      vref=-0.038d0        ! asymptotic V value
!       vref=-619.8401075d0  ! asymptotic E value

      call splie2(x1a,x2a,ya,m,n,y2a)


cc****************************
cc PLOTS: Reactant Jacobi Coordinates
cc****************************

      open(25,file='cnmar_pot_V.jac',status='unknown')
!      open(25,file='cnmar_pot_E.jac',status='unknown')
      do ia=1,nang+1
         x1=x1min+da*dble(ia-1)
         do ir=1,npun+1
           x2=x2min+dr*dble(ir-1)
          call splin2(x1a,x2a,ya,y2a,m,n,x1,x2,y)
          write(25,100)x1,x2,(y-vref)*ev2cm
!          write(25,100)x1,x2,(y-vref)/h2cm
         enddo
        write(25,*)
      enddo
      close(25)


       stop
       end



C************************************************************
      SUBROUTINE splin2(x1a,x2a,ya,y2a,m,n,x1,x2,y)
      INTEGER*4 m,n,NN
      real*8 x1,x2,y,x1a(m),x2a(n),y2a(m,n),ya(m,n)
      PARAMETER (NN=100)
CU    USES spline,splint
      INTEGER*4 j,k
      REAL*8 y2tmp(NN),ytmp(NN),yytmp(NN)
      do 12 j=1,m
        do 11 k=1,n
          ytmp(k)=ya(j,k)
          y2tmp(k)=y2a(j,k)
11      continue
        call splint(x2a,ytmp,y2tmp,n,x2,yytmp(j))
12    continue
      call spline(x1a,yytmp,m,1.d30,1.d30,y2tmp)
      call splint(x1a,yytmp,y2tmp,m,x1,y)
      return
      END
C  (C) Copr. 1986-92 Numerical Recipes Software *1n#!-013.
C**********************************************************
      SUBROUTINE spline(x,y,n,yp1,ypn,y2)
      INTEGER*4 n,NMAX
      REAL*8 yp1,ypn,x(n),y(n),y2(n)
      PARAMETER (NMAX=500)
      INTEGER i,k
      REAL*8 p,qn,sig,un,u(NMAX)
      if (yp1.gt..99d30) then
        y2(1)=0.d0
        u(1)=0.d0
      else
        y2(1)=-0.5d0
        u(1)=(3.d0/(x(2)-x(1)))*((y(2)-y(1))/(x(2)-x(1))-yp1)
      endif
      do 11 i=2,n-1
        sig=(x(i)-x(i-1))/(x(i+1)-x(i-1))
        p=sig*y2(i-1)+2.d0
        y2(i)=(sig-1.d0)/p
        u(i)=(6.d0*((y(i+1)-y(i))/(x(i+
     *1)-x(i))-(y(i)-y(i-1))/(x(i)-x(i-1)))/(x(i+1)-x(i-1))-sig*
     *u(i-1))/p
11    continue
      if (ypn.gt..99d30) then
        qn=0.d0
        un=0.d0
      else
        qn=0.5d0
        un=(3.d0/(x(n)-x(n-1)))*(ypn-(y(n)-y(n-1))/(x(n)-x(n-1)))
      endif
      y2(n)=(un-qn*u(n-1))/(qn*y2(n-1)+1.d0)
      do 12 k=n-1,1,-1
        y2(k)=y2(k)*y2(k+1)+u(k)
12    continue
      return
      END
C  (C) Copr. 1986-92 Numerical Recipes Software *1n#!-013.
C**********************************************************
      SUBROUTINE splint(xa,ya,y2a,n,x,y)
      INTEGER*4 n
      REAL*8 x,y,xa(n),y2a(n),ya(n)
      INTEGER*4 k,khi,klo
      REAL*8 a,b,h
      klo=1
      khi=n
1     if (khi-klo.gt.1) then
        k=(khi+klo)/2
        if(xa(k).gt.x)then
          khi=k
        else
          klo=k
        endif
      goto 1
      endif
      h=xa(khi)-xa(klo)
      if (h.eq.0.d0)then
      write(*,*)"h=",h,xa(khi),xa(klo),n,klo,khi
      pause 'bad xa input in splint'
      endif
      a=(xa(khi)-x)/h
      b=(x-xa(klo))/h
      y=a*ya(klo)+b*ya(khi)+((a**3-a)*y2a(klo)+(b**3-b)*y2a(khi))*(h**
     *2)/6.d0
      return
      END
C  (C) Copr. 1986-92 Numerical Recipes Software *1n#!-013.
C**********************************************************
      SUBROUTINE splie2(x1a,x2a,ya,m,n,y2a)
      INTEGER*4 m,n,NN
      REAL*8 x1a(m),x2a(n),y2a(m,n),ya(m,n)
      PARAMETER (NN=100)
CU    USES spline
      INTEGER*4 j,k
      REAL*8 y2tmp(NN),ytmp(NN)
      do 13 j=1,m
        do 11 k=1,n
          ytmp(k)=ya(j,k)
11      continue
        call spline(x2a,ytmp,n,1.d30,1.d30,y2tmp)
        do 12 k=1,n
          y2a(j,k)=y2tmp(k)
12      continue
13    continue
      return
      END
C  (C) Copr. 1986-92 Numerical Recipes Software *1n#!-013.
C**********************************************************
